@@ -1,5 +1,5 @@
-/* Fault handler information.  Linux/SPARC version.
-   Copyright (C) 2002  Bruno Haible <bruno@clisp.org>
+/* Fault handler information.  Linux/SPARC version when it supports POSIX.
+   Copyright (C) 2009  Bruno Haible <bruno@clisp.org>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,9 +15,16 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
-#include <asm/sigcontext.h>
+#include "fault-posix-ucontext.h"
 
-#define SIGSEGV_FAULT_HANDLER_ARGLIST  int sig, int code, struct sigcontext *scp, void *addr /* FIXME */
-#define SIGSEGV_FAULT_ADDRESS  addr  /* in case of SunOS4 signal frames */
-#define SIGSEGV_FAULT_CONTEXT  scp
-#define SIGSEGV_FAULT_STACKPOINTER  scp->sigc_sp /* FIXME: not scp->si_regs.u_regs[14] ? */
+/* See glibc/sysdeps/unix/sysv/linux/sparc/sys/ucontext.h
+   and the definition of GET_STACK in
+   glibc/sysdeps/unix/sysv/linux/sparc/{sparc32,sparc64}/sigcontextinfo.h.
+   Note that the 'mcontext_t' defined in
+   glibc/sysdeps/unix/sysv/linux/sparc/sys/ucontext.h
+   and the 'struct sigcontext' defined in
+   glibc/sysdeps/unix/sysv/linux/sparc/bits/sigcontext.h
+   (see also <asm/sigcontext.h>)
+   are quite different types.  */
+
+#define SIGSEGV_FAULT_STACKPOINTER  ((ucontext_t *) ucp)->uc_mcontext.gregs[REG_O6]
